@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // preset.cpp: Class for representing effect presets
-// Copyright (C) 2000-2002,2004-2007 Kai Vehmanen
+// Copyright (C) 2000-2002,2004-2007,2009 Kai Vehmanen
 // Copyright (C) 2001 Arto Hamara
 //
 // Attributes:
@@ -108,11 +108,6 @@ void PRESET::set_samples_per_second(SAMPLE_SPECS::sample_rate_t v)
     chains[q]->set_samples_per_second(v);
   }
 
-  for(size_t n = 0; n < impl_repp->gctrls_rep.size(); n++) {
-    impl_repp->gctrls_rep[n]->set_samples_per_second(v);
-  }
-
-  
   ECA_SAMPLERATE_AWARE::set_samples_per_second(v);
 }
 
@@ -513,7 +508,6 @@ CHAIN_OPERATOR::parameter_t PRESET::get_parameter(int param) const
 {
   if (param > 0 && param <= static_cast<int>(impl_repp->slave_param_objects_rep.size())) {
     DBC_CHECK(static_cast<int>(impl_repp->slave_param_indices_rep.size()) > param - 1);
-    DBC_CHECK(impl_repp->slave_param_indices_rep[param - 1].size() > 0);
 
     if (impl_repp->slave_param_indices_rep[param - 1].size() > 0) {
       int index = impl_repp->slave_param_indices_rep[param - 1][0];
@@ -545,7 +539,6 @@ void PRESET::init(SAMPLE_BUFFER *insample)
 
   for(size_t n = 0; n < impl_repp->gctrls_rep.size(); n++) {
     impl_repp->gctrls_rep[n]->init();
-    impl_repp->gctrls_rep[n]->set_samples_per_second(samples_per_second());
   }
 }
 
@@ -566,7 +559,7 @@ void PRESET::process(void)
 {
   vector<SAMPLE_BUFFER*>::iterator p = buffers.begin();
   while(p != buffers.end()) {
-    (*p)->copy(*first_buffer);
+    (*p)->copy_all_content(*first_buffer);
     ++p;
   }
 
